<?php
/*
 * Copyright 2000-2002 Sun Microsystems, Inc.  All rights reserved.
 * $Id: userModHandler.php,v 1.32 2002/03/26 20:59:12 pbaltz Exp $
 */

include("ArrayPacker.php");
include("ServerScriptHelper.php");
include("AutoFeatures.php");

$serverScriptHelper = new ServerScriptHelper();
$autoFeatures = new AutoFeatures($serverScriptHelper);
$cceClient = $serverScriptHelper->getCceClient();

$oids = $cceClient->find("User", array("name" => $userNameField));
$iam = $serverScriptHelper->getLoginName();

// modify user
$attributes = array("fullName" => $fullNameField);
if($sortNameField)
  $attributes["sortName"]=$sortNameField;
if($passwordField)
  $attributes["password"] = $passwordField;
$obj = $cceClient->get($oids[0], "");
if (!$obj["desc_readonly"]) {
  $attributes["description"] = $userDescField;	
}

# don't set this attribute now if a siteadmin is trying to demote himself
if (isset($siteAdministrator) && ($siteAdministrator || (!$siteAdministrator && ($iam != $userNameField))))
  $attributes["capLevels"] = ($siteAdministrator ? '&siteAdmin&' : '');

if (isset($suspendUser))
  $attributes['ui_enabled'] = ($suspendUser) ? '0' : '1';

$cceClient->set($oids[0], "", $attributes);
$errors = $cceClient->errors();

for ($i = 0; $i < count($errors); $i++) {
	if ( ($errors[$i]->code == 2) && ($errors[$i]->key === "password"))
	{
		$errors[$i]->message = "[[base-user.error-invalid-password]]";
	}
}



// set quota
if(!$maxDiskSpaceField)
	$maxDiskSpaceField = -1;

$cceClient->set($oids[0], "Disk", array("quota" => $maxDiskSpaceField));
$errors = array_merge($errors, $cceClient->errors());

if ( isset( $group ) && $group != "" )
  $site = $group;

// handle autofeatures
list($userservices) = $cceClient->find("UserServices", array("site" => $site));
$af_errors = $autoFeatures->handle("modify.User", array("CCE_SERVICES_OID" =>
$userservices, "CCE_OID" => $oids[0]));
$errors = array_merge($errors, $af_errors);

$userNames = $cceClient->names("User");

// set group membership
$memberGroups = stringToArray($memberGroupsField);
$goids = $cceClient->find("Workgroup");
for($i = 0; $i < count($goids); $i++) {
  $group = $cceClient->get($goids[$i]);
  $members = stringToArray($group["members"]);

  if(in_array($group["name"], $memberGroups)) {
    // add user to group
    $found = false;
    for($j = 0; $j < count($members); $j++)
	if($members[$j] == $userNameField) {
	  $found = true;
	  break;
	}
    if(!$found)
	$members[] = $userNameField;
  }
  else {
    // remove user from group
    for($j = 0; $j < count($members); $j++)
	if($members[$j] == $userNameField) {
	  array_splice($members, $j, 1);
	  break;
	}
  }

  // update CCE
  $cceClient->set($goids[$i], "", array("members" => arrayToString($members)));
  $errors = array_merge($errors, $cceClient->errors());
}

// set email forwarding info
$cceClient->set($oids[0], "Email", array(
	"forwardEnable" => ($forwardEnableField ? 1 : 0), 
	"forwardEmail" => $forwardEmailField, 
	"forwardSave" => $forwardSaveField));
$errors = array_merge($errors, $cceClient->errors());

// set email aliases info

//Prune the duplicate email aliases
$emailAliasesFieldArray = $cceClient->scalar_to_array($emailAliasesField);
$emailAliasesFieldArray = array_unique($emailAliasesFieldArray);
$emailAliasesField = $cceClient->array_to_scalar($emailAliasesFieldArray);

// replace && with &, to avoid always getting a blank alias in the field
// in cce, this also skirts around dealing with browser issues
$emailAliasesField = str_replace("&&", "&", $emailAliasesField);
if ($emailAliasesField == '&') {
	$emailAliasesField = '';
}

$attributes = array("aliases" => $emailAliasesField);
#if ( isset($apop) ) 
#  $attributes["apop"] = $apop;

$cceClient->set($oids[0], "Email", $attributes);
$errors = array_merge($errors, $cceClient->errors());

// set vacation info
$cceClient->set($oids[0], "Email", array( 
	"vacationOn" => ($autoResponderField ? 1 : 0), 
	"vacationMsg" => $autoResponderMessageField));
$errors = array_merge($errors, $cceClient->errors());

# log the user out if they are trying to demote themself
if (isset($siteAdministrator) && !$siteAdministrator && ($iam == $userNameField)) {
  $cceClient->set($oids[0], "", array('capLevels' => ''));
  print($serverScriptHelper->toHandlerHtml("/logoutHandler.php"));
  $serverScriptHelper->destructor();
  exit(0);
}

print($serverScriptHelper->toHandlerHtml("/base/user/userList.php?group=" . $obj["site"], $errors, false));

$serverScriptHelper->destructor();
?>
